Learn R Programming

multiness (version 1.0.2)

agri_trade: Agricultural trade multiplex network

Description

An undirected multiplex network containing trade volumes for 13 highly traded agricultural products for the year 2010, collected by the Food and Agriculture Organization of the United Nations (FAO). The original data set can be downloaded from Manlio DeDomenico's website. Array entries are in units of tonnes (metric tons) of bilateral trade of a given agricultural product. For further documentation and product definitions see https://www.fao.org/faostat/en/#definitions/.

Usage

data(agri_trade)

Arguments

Format

An array of dimension \(145 \times 145 \times 13\).

References

DeDomenico et al. (2015) Nature Communications